pub struct BytePos(pub u32);Expand description
A byte offset. Keep this small (currently 32-bits), as AST contains a lot of them.
Reserved
-
0 is reserved for dummy spans. It means
BytePos(0)means theBytePosis synthesized by the compiler. -
Values larger than
u32::MAX - 2^16are reserved for the comments.
u32::MAX is special value used to generate source map entries.
Tuple Fields
0: u32Implementations
Sourceimpl BytePos
impl BytePos
Sourcepub const PLACEHOLDER: BytePos
pub const PLACEHOLDER: BytePos
Placeholders, commonly used where names are required, but the names are not referenced elsewhere.
Sourcepub const SYNTHESIZED: BytePos
pub const SYNTHESIZED: BytePos
Synthesized, but should be stored in a source map.
pub const fn is_reserved_for_comments(self) -> bool
Sourcepub const fn is_dummy(self) -> bool
pub const fn is_dummy(self) -> bool
Returns `true`` if this is synthesized and has no relevant input source code.
pub const fn is_pure(self) -> bool
pub const fn is_placeholder(self) -> bool
Sourcepub const fn can_have_comment(self) -> bool
pub const fn can_have_comment(self) -> bool
Returns `true`` if this is explicitly synthesized or has relevant input source so can have a comment.