pub struct SyntaxContext(/* private fields */);Expand description
A SyntaxContext represents a chain of macro expansions (represented by marks).
Implementations
Sourceimpl SyntaxContext
impl SyntaxContext
Sourcepub fn within_ignored_ctxt<F, Ret>(op: F) -> Retwhere
F: FnOnce() -> Ret,
pub fn within_ignored_ctxt<F, Ret>(op: F) -> Retwhere
F: FnOnce() -> Ret,
In op, EqIgnoreSpan of [Ident] will ignore the syntax context.
Sourceimpl SyntaxContext
impl SyntaxContext
pub const fn empty() -> SyntaxContext
Sourcepub fn has_mark(self, mark: Mark) -> bool
pub fn has_mark(self, mark: Mark) -> bool
Returns true if self is marked with mark.
Panics if mark is not a valid mark.
pub fn as_u32(self) -> u32
pub fn from_u32(raw: u32) -> SyntaxContext
Sourcepub fn apply_mark(self, mark: Mark) -> SyntaxContext
pub fn apply_mark(self, mark: Mark) -> SyntaxContext
Extend a syntax context with a given mark and default transparency for that mark.
Sourcepub fn remove_mark(&mut self) -> Mark
pub fn remove_mark(&mut self) -> Mark
Pulls a single mark off of the syntax context. This effectively moves the context up one macro definition level. That is, if we have a nested macro definition as follows:
macro_rules! f {
macro_rules! g {
...
}
}and we have a SyntaxContext that is referring to something declared by an invocation of g (call it g1), calling remove_mark will result in the SyntaxContext for the invocation of f that created g1. Returns the mark that was removed.
pub fn outer(self) -> Mark